@@ -9,15 +9,15 @@
  *          Gerg rdi <cactus@cactus.rulez.org>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -322,12 +322,12 @@ contacts_changed_cb (EBookView *book_view, const GList *contacts, gpointer user_
 
         for (i = contacts; i; i = i->next) {
                 EContact *contact = E_CONTACT (i->data);
-                char *uid = e_contact_get_const (contact, E_CONTACT_UID);
+                const char *uid = e_contact_get_const (contact, E_CONTACT_UID);
                 
                 /* If no date is set, remove from list of tracked contacts */                 
                 if (!e_contact_get (contact, E_CONTACT_BIRTH_DATE) &&
                     !e_contact_get (contact, E_CONTACT_ANNIVERSARY)) {
-                        g_hash_table_remove (cbc->priv->tracked_contacts, uid);
+                        g_hash_table_remove (cbc->priv->tracked_contacts, (char *)uid);
                 } else {
                         ContactRecord *cr = contact_record_new (cbc, contact);
                         g_hash_table_insert (cbc->priv->tracked_contacts, g_strdup (uid), cr);
@@ -345,14 +345,20 @@ contacts_added_cb (EBookView *book_view, const GList *contacts, gpointer user_da
         for (i = contacts; i; i = i->next)
         {
                 EContact *contact = E_CONTACT (i->data);
+                EContactDate *birthday, *anniversary;
                 
-                if (e_contact_get (contact, E_CONTACT_BIRTH_DATE) ||
-                    e_contact_get (contact, E_CONTACT_ANNIVERSARY)) {
+                birthday = e_contact_get (contact, E_CONTACT_BIRTH_DATE);
+                anniversary = e_contact_get (contact, E_CONTACT_ANNIVERSARY);
+                                             
+                if (birthday || anniversary) {
                         ContactRecord *cr = contact_record_new (cbc, contact);
                         const char    *uid = e_contact_get_const (contact, E_CONTACT_UID);
                         
                         g_hash_table_insert (cbc->priv->tracked_contacts, g_strdup (uid), cr);
                 }
+                
+                e_contact_date_free (birthday);
+                e_contact_date_free (anniversary);
         }
 }
 
@@ -400,12 +406,12 @@ create_component (ECalBackendContacts *cbc, const char *uid, EContactDate *cdate
         ECalComponentDateTime      dt;
 	struct icalrecurrencetype  r;
         GSList recur_list;
-	
+
         g_return_val_if_fail (E_IS_CAL_BACKEND_CONTACTS (cbc), 0);
 
         if (!cdate)
                 return NULL;
-        
+
         ical_comp = icalcomponent_new (ICAL_VEVENT_COMPONENT);
 	
         /* Create the event object */
@@ -443,7 +449,11 @@ create_component (ECalBackendContacts *cbc, const char *uid, EContactDate *cdate
         e_cal_component_set_summary (cal_comp, &comp_summary);
 	
 	/* Set category and visibility */
-	e_cal_component_set_categories (cal_comp, _("Birthday"));
+	if (g_str_has_suffix (uid, ANNIVERSARY_UID_EXT))
+		e_cal_component_set_categories (cal_comp, _("Anniversary"));
+	else if (g_str_has_suffix (uid, BIRTHDAY_UID_EXT))
+		e_cal_component_set_categories (cal_comp, _("Birthday"));
+	
 	e_cal_component_set_classification (cal_comp, E_CAL_COMPONENT_CLASS_PRIVATE);
 
 	/* Birthdays/anniversaries are shown as free time */
@@ -461,16 +471,19 @@ create_birthday (ECalBackendContacts *cbc, EContact *contact)
         EContactDate  *cdate;
         ECalComponent *cal_comp;
 	char          *summary;
-        const char    *name, *uid;
+        const char    *name;
+        char *uid;
 
         cdate = e_contact_get (contact, E_CONTACT_BIRTH_DATE);
         name = e_contact_get_const (contact, E_CONTACT_FILE_AS);
 
-	uid = g_strdup_printf ("%s%s", (char *) e_contact_get (contact, E_CONTACT_UID), BIRTHDAY_UID_EXT);
+	uid = g_strdup_printf ("%s%s", (char *) e_contact_get_const (contact, E_CONTACT_UID), BIRTHDAY_UID_EXT);
         summary = g_strdup_printf (_("Birthday: %s"), name);
         
         cal_comp = create_component (cbc, uid, cdate, summary);
 
+        e_contact_date_free (cdate);
+        g_free (uid);
         g_free (summary);
         
         return cal_comp;
@@ -482,16 +495,19 @@ create_anniversary (ECalBackendContacts *cbc, EContact *contact)
         EContactDate  *cdate;
         ECalComponent *cal_comp;
 	char          *summary;
-        const char    *name, *uid;
+        const char    *name;
+        char *uid;
         
         cdate = e_contact_get (contact, E_CONTACT_ANNIVERSARY);
         name = e_contact_get_const (contact, E_CONTACT_FILE_AS);
 
-	uid = g_strdup_printf ("%s%s", (char *) e_contact_get (contact, E_CONTACT_UID), ANNIVERSARY_UID_EXT);
+	uid = g_strdup_printf ("%s%s", (char *) e_contact_get_const (contact, E_CONTACT_UID), ANNIVERSARY_UID_EXT);
         summary = g_strdup_printf (_("Anniversary: %s"), name);
         
         cal_comp = create_component (cbc, uid, cdate, summary);
 
+        e_contact_date_free (cdate);
+        g_free (uid);
         g_free (summary);
 
         return cal_comp;
@@ -583,14 +599,14 @@ e_cal_backend_contacts_get_object (ECalBackendSync *backend, EDataCal *cal,
 	if (!record)
 		return GNOME_Evolution_Calendar_ObjectNotFound;
 
-        if (record->comp_birthday) {
+        if (record->comp_birthday && g_str_has_suffix (uid, BIRTHDAY_UID_EXT)) {
                 *object = e_cal_component_get_as_string (record->comp_birthday);
 		
 		d(g_message ("Return birthday: %s", *object));
 		return GNOME_Evolution_Calendar_Success;
 	}
 	
-        if (record->comp_anniversary) {
+        if (record->comp_anniversary && g_str_has_suffix (uid, ANNIVERSARY_UID_EXT)) {
                 *object = e_cal_component_get_as_string (record->comp_anniversary);
 
 		d(g_message ("Return anniversary: %s", *object));
@@ -925,7 +941,7 @@ e_cal_backend_contacts_init (ECalBackendContacts *cbc, ECalBackendContactsClass
 	e_book_get_addressbooks (&priv->addressbook_sources, NULL);
 
         priv->addressbooks = g_hash_table_new_full (g_str_hash, g_str_equal,
-                                                    g_free, (GDestroyNotify)book_record_free);
+                                                    g_free, (GDestroyNotify) book_record_free);
         priv->tracked_contacts = g_hash_table_new_full (g_str_hash, g_str_equal,
                                                         g_free, (GDestroyNotify)contact_record_free);
         
