@@ -6,15 +6,15 @@
  * Authors: Hans Petter Jansson <hpj@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  *
@@ -24,9 +24,10 @@
 #include <config.h>
 #include <string.h>
 #include <unistd.h>
+#include <gconf/gconf-client.h>
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker-util.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n-lib.h>
 #include <libedataserver/e-xml-hash-utils.h>
 #include <libecal/e-cal-recur.h>
 #include <libecal/e-cal-util.h>
@@ -200,7 +201,7 @@ notify_and_remove_from_cache (gpointer key, gpointer value, gpointer user_data)
 	const char *calobj = value;
 	ECalBackendHttp *cbhttp = E_CAL_BACKEND_HTTP (user_data);
 
-	e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbhttp), uid, calobj);
+	e_cal_backend_notify_object_removed (E_CAL_BACKEND (cbhttp), uid, calobj, NULL);
 
 	return TRUE;
 }
@@ -288,11 +289,20 @@ retrieval_done (SoupMessage *msg, ECalBackendHttp *cbhttp)
 
 	kind = e_cal_backend_get_kind (E_CAL_BACKEND (cbhttp));
 	subcomp = icalcomponent_get_first_component (icalcomp, ICAL_ANY_COMPONENT);
+	e_file_cache_freeze_changes (E_FILE_CACHE (priv->cache));
 	while (subcomp) {
 		ECalComponent *comp;
 		icalcomponent_kind subcomp_kind;
+		icalproperty *prop = NULL;
 
 		subcomp_kind = icalcomponent_isa (subcomp);
+		prop = icalcomponent_get_first_property (subcomp, ICAL_UID_PROPERTY);
+		if (!prop) {
+			g_warning (" The component does not have the  mandatory property UID \n");
+			subcomp = icalcomponent_get_next_component (icalcomp, kind);
+			continue;
+		}
+
 		if (subcomp_kind == kind) {
 			comp = e_cal_component_new ();
 			if (e_cal_component_set_icalcomponent (comp, subcomp)) {
@@ -301,7 +311,7 @@ retrieval_done (SoupMessage *msg, ECalBackendHttp *cbhttp)
 				e_cal_backend_cache_put_component (priv->cache, comp);
 
 				e_cal_component_get_uid (comp, &uid);
-				if (g_hash_table_lookup_extended (old_cache, uid, &orig_key, &orig_value)) {
+				if (g_hash_table_lookup_extended (old_cache, uid, (void **)&orig_key, (void **)&orig_value)) {
 					e_cal_backend_notify_object_modified (E_CAL_BACKEND (cbhttp),
 									      orig_value,
 									      icalcomponent_as_ical_string (subcomp));
@@ -326,6 +336,8 @@ retrieval_done (SoupMessage *msg, ECalBackendHttp *cbhttp)
 		subcomp = icalcomponent_get_next_component (icalcomp, kind);
 	}
 
+	e_file_cache_thaw_changes (E_FILE_CACHE (priv->cache));
+
 	/* notify the removals */
 	g_hash_table_foreach_remove (old_cache, (GHRFunc) notify_and_remove_from_cache, cbhttp);
 	g_hash_table_destroy (old_cache);
@@ -361,7 +373,48 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 
 	/* create the Soup session if not already created */
 	if (!priv->soup_session) {
+		GConfClient *conf_client;
+
 		priv->soup_session = soup_session_async_new ();
+
+		/* set the HTTP proxy, if configuration is set to do so */
+		conf_client = gconf_client_get_default ();
+		if (gconf_client_get_bool (conf_client, "/system/http_proxy/use_http_proxy", NULL)) {
+			char *server, *proxy_uri;
+			int port;
+
+			server = gconf_client_get_string (conf_client, "/system/http_proxy/host", NULL);
+			port = gconf_client_get_int (conf_client, "/system/http_proxy/port", NULL);
+
+			if (server && server[0]) {
+				SoupUri *suri;
+				if (gconf_client_get_bool (conf_client, "/system/http_proxy/use_authentication", NULL)) {
+					char *user, *password;
+
+					user = gconf_client_get_string (conf_client,
+									"/system/http_proxy/authentication_user",
+									NULL);
+					password = gconf_client_get_string (conf_client,
+									    "/system/http_proxy/authentication_password",
+									    NULL);
+
+					proxy_uri = g_strdup_printf("http://%s:%s@%s:%d", user, password, server, port);
+
+					g_free (user);
+					g_free (password);
+				} else
+					proxy_uri = g_strdup_printf ("http://%s:%d", server, port);
+
+				suri = soup_uri_new (proxy_uri);
+				g_object_set (G_OBJECT (priv->soup_session), SOUP_SESSION_PROXY_URI, suri, NULL);
+
+				soup_uri_free (suri);
+				g_free (server);
+				g_free (proxy_uri);
+			}
+		}
+
+		g_object_unref (conf_client);
 	}
 
 	if (priv->uri == NULL)
@@ -369,6 +422,8 @@ begin_retrieval_cb (ECalBackendHttp *cbhttp)
 
 	/* create message to be sent to server */
 	soup_message = soup_message_new (SOUP_METHOD_GET, priv->uri);
+	soup_message_add_header (soup_message->request_headers, "User-Agent",
+				 "Evolution/" VERSION);
 	soup_message_set_flags (soup_message, SOUP_MESSAGE_NO_REDIRECT);
 
 	soup_session_queue_message (priv->soup_session, soup_message,
@@ -436,8 +491,13 @@ e_cal_backend_http_open (ECalBackendSync *backend, EDataCal *cal, gboolean only_
 	if (!priv->cache) {
 		priv->cache = e_cal_backend_cache_new (e_cal_backend_get_uri (E_CAL_BACKEND (backend)));
 
-		/* FIXME: no need to set it online here when we implement the online/offline stuff correctly */
-		priv->mode = CAL_MODE_REMOTE;
+		if (!priv->cache) {
+			e_cal_backend_notify_error (E_CAL_BACKEND(cbhttp), _("Could not create cache file"));
+			return GNOME_Evolution_Calendar_OtherError;	
+		}
+		if (priv->mode == CAL_MODE_LOCAL)
+			return GNOME_Evolution_Calendar_Success;
+
 		g_idle_add ((GSourceFunc) begin_retrieval_cb, cbhttp);
 	}
 
@@ -496,17 +556,29 @@ e_cal_backend_http_set_mode (ECalBackend *backend, CalMode mode)
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
 	GNOME_Evolution_Calendar_CalMode set_mode;
-
+	gboolean loaded;
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
 	priv = cbhttp->priv;
 
+	loaded = e_cal_backend_http_is_loaded (backend);
+				
 	switch (mode) {
 		case CAL_MODE_LOCAL:
-		case CAL_MODE_REMOTE:
 			priv->mode = mode;
 			set_mode = cal_mode_to_corba (mode);
+			if (loaded && priv->reload_timeout_id) {
+				g_source_remove (priv->reload_timeout_id);
+				priv->reload_timeout_id = 0;
+			}
 			break;
-		case CAL_MODE_ANY:
+		case CAL_MODE_REMOTE:
+		case CAL_MODE_ANY:	
+			priv->mode = mode;
+			set_mode = cal_mode_to_corba (mode);
+			if (loaded) 
+				g_idle_add ((GSourceFunc) begin_retrieval_cb, backend);
+			break;
+		
 			priv->mode = CAL_MODE_REMOTE;
 			set_mode = GNOME_Evolution_Calendar_MODE_REMOTE;
 			break;
@@ -515,14 +587,17 @@ e_cal_backend_http_set_mode (ECalBackend *backend, CalMode mode)
 			break;
 	}
 
-	if (set_mode == GNOME_Evolution_Calendar_MODE_ANY)
-		e_cal_backend_notify_mode (backend,
-					   GNOME_Evolution_Calendar_CalListener_MODE_NOT_SUPPORTED,
-					   cal_mode_to_corba (priv->mode));
-	else
-		e_cal_backend_notify_mode (backend,
-					   GNOME_Evolution_Calendar_CalListener_MODE_SET,
-					   set_mode);
+	if (loaded) {
+		
+		if (set_mode == GNOME_Evolution_Calendar_MODE_ANY)
+			e_cal_backend_notify_mode (backend,
+						   GNOME_Evolution_Calendar_CalListener_MODE_NOT_SUPPORTED,
+						   cal_mode_to_corba (priv->mode));
+		else
+			e_cal_backend_notify_mode (backend,
+						   GNOME_Evolution_Calendar_CalListener_MODE_SET,
+						   set_mode);
+	}
 }
 
 static ECalBackendSyncStatus
@@ -576,7 +651,7 @@ e_cal_backend_http_get_timezone (ECalBackendSync *backend, EDataCal *cal, const
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
-	icaltimezone *zone;
+	const icaltimezone *zone;
 	icalcomponent *icalcomp;
 
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
@@ -584,11 +659,15 @@ e_cal_backend_http_get_timezone (ECalBackendSync *backend, EDataCal *cal, const
 
 	g_return_val_if_fail (tzid != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
 
-	zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
-	if (!zone)
-		return GNOME_Evolution_Calendar_ObjectNotFound;
+	/* first try to get the timezone from the cache */
+	zone = e_cal_backend_cache_get_timezone (priv->cache, tzid);
+	if (!zone) {
+		zone = icaltimezone_get_builtin_timezone_from_tzid (tzid);
+		if (!zone)
+			return GNOME_Evolution_Calendar_ObjectNotFound;
+	}
 
-	icalcomp = icaltimezone_get_component (zone);
+	icalcomp = icaltimezone_get_component ((icaltimezone *)zone);
 	if (!icalcomp)
 		return GNOME_Evolution_Calendar_InvalidObject;
 
@@ -603,6 +682,8 @@ e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
+	icalcomponent *tz_comp;
+	icaltimezone *zone;
 
 	cbhttp = (ECalBackendHttp *) backend;
 
@@ -611,7 +692,19 @@ e_cal_backend_http_add_timezone (ECalBackendSync *backend, EDataCal *cal, const
 
 	priv = cbhttp->priv;
 
-	/* FIXME: add the timezone to the cache */
+	tz_comp = icalparser_parse_string (tzobj);
+	if (!tz_comp)
+		return GNOME_Evolution_Calendar_InvalidObject;
+
+	if (icalcomponent_isa (tz_comp) != ICAL_VTIMEZONE_COMPONENT) {
+		icalcomponent_free (tz_comp);
+		return GNOME_Evolution_Calendar_InvalidObject;
+	}
+
+	zone = icaltimezone_new ();
+	icaltimezone_set_component (zone, tz_comp);
+	e_cal_backend_cache_put_timezone (priv->cache, zone);
+
 	return GNOME_Evolution_Calendar_Success;
 }
 
@@ -702,6 +795,140 @@ e_cal_backend_http_start_query (ECalBackend *backend, EDataCalView *query)
 	e_data_cal_view_notify_done (query, GNOME_Evolution_Calendar_Success);
 }
 
+
+static icaltimezone *
+resolve_tzid (const char *tzid, gpointer user_data)
+{
+        icalcomponent *vcalendar_comp = user_data;
+
+        if (!tzid || !tzid[0])
+                return NULL;
+        else if (!strcmp (tzid, "UTC"))
+                return icaltimezone_get_utc_timezone ();
+
+        return icalcomponent_get_timezone (vcalendar_comp, tzid);
+}
+
+
+static gboolean
+free_busy_instance (ECalComponent *comp,
+                    time_t        instance_start,
+                    time_t        instance_end,
+                    gpointer      data)
+{
+        icalcomponent *vfb = data;
+        icalproperty *prop;
+        icalparameter *param;
+        struct icalperiodtype ipt;
+        icaltimezone *utc_zone;
+
+        utc_zone = icaltimezone_get_utc_timezone ();
+
+        ipt.start = icaltime_from_timet_with_zone (instance_start, FALSE, utc_zone);
+        ipt.end = icaltime_from_timet_with_zone (instance_end, FALSE, utc_zone);
+        ipt.duration = icaldurationtype_null_duration ();
+
+        /* add busy information to the vfb component */
+        prop = icalproperty_new (ICAL_FREEBUSY_PROPERTY);
+        icalproperty_set_freebusy (prop, ipt);
+
+        param = icalparameter_new_fbtype (ICAL_FBTYPE_BUSY);
+        icalproperty_add_parameter (prop, param);
+
+        icalcomponent_add_property (vfb, prop);
+
+        return TRUE;
+}
+
+static icalcomponent *
+create_user_free_busy (ECalBackendHttp *cbhttp, const char *address, const char *cn,
+                       time_t start, time_t end)
+{
+        GList *list = NULL, *l;
+        icalcomponent *vfb;
+        icaltimezone *utc_zone;
+        ECalBackendSExp *obj_sexp;
+        ECalBackendHttpPrivate *priv;
+        ECalBackendCache *cache;
+        char *query, *iso_start, *iso_end;
+	
+        priv = cbhttp->priv;
+        cache = priv->cache;
+
+        /* create the (unique) VFREEBUSY object that we'll return */
+        vfb = icalcomponent_new_vfreebusy ();
+        if (address != NULL) {
+                icalproperty *prop;
+                icalparameter *param;
+
+                prop = icalproperty_new_organizer (address);
+                if (prop != NULL && cn != NULL) {
+                        param = icalparameter_new_cn (cn);
+                        icalproperty_add_parameter (prop, param);
+                }
+                if (prop != NULL)
+                        icalcomponent_add_property (vfb, prop);
+        }
+        utc_zone = icaltimezone_get_utc_timezone ();
+        icalcomponent_set_dtstart (vfb, icaltime_from_timet_with_zone (start, FALSE, utc_zone));
+        icalcomponent_set_dtend (vfb, icaltime_from_timet_with_zone (end, FALSE, utc_zone));
+
+        /* add all objects in the given interval */
+        iso_start = isodate_from_time_t (start);
+        iso_end = isodate_from_time_t (end);
+        query = g_strdup_printf ("occur-in-time-range? (make-time \"%s\") (make-time \"%s\")",
+                                 iso_start, iso_end);
+        obj_sexp = e_cal_backend_sexp_new (query);
+        g_free (query);
+        g_free (iso_start);
+        g_free (iso_end);
+
+        if (!obj_sexp)
+                return vfb;
+        if (!obj_sexp)
+                return vfb;
+
+        list = e_cal_backend_cache_get_components(cache);
+
+        for (l = list; l; l = l->next) {
+                ECalComponent *comp = l->data;
+                icalcomponent *icalcomp, *vcalendar_comp;
+                icalproperty *prop;
+
+                icalcomp = e_cal_component_get_icalcomponent (comp);
+                if (!icalcomp)
+                        continue;
+
+                /* If the event is TRANSPARENT, skip it. */
+                prop = icalcomponent_get_first_property (icalcomp,
+                                                         ICAL_TRANSP_PROPERTY);
+                if (prop) {
+                        icalproperty_transp transp_val = icalproperty_get_transp (prop);
+                        if (transp_val == ICAL_TRANSP_TRANSPARENT ||
+                            transp_val == ICAL_TRANSP_TRANSPARENTNOCONFLICT)
+                                continue;
+                }
+
+                if (!e_cal_backend_sexp_match_comp (obj_sexp, l->data, E_CAL_BACKEND (cbhttp)))
+                        continue;
+
+                vcalendar_comp = icalcomponent_get_parent (icalcomp);
+                if (!vcalendar_comp)
+                        vcalendar_comp = icalcomp;
+                e_cal_recur_generate_instances (comp, start, end,
+                                                free_busy_instance,
+                                                vfb,
+                                                resolve_tzid,
+                                                vcalendar_comp,
+                                                e_cal_backend_cache_get_default_timezone (cache));
+        }
+        g_object_unref (obj_sexp);
+
+        return vfb;
+}
+
+
+
 /* Get_free_busy handler for the file backend */
 static ECalBackendSyncStatus
 e_cal_backend_http_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GList *users,
@@ -709,6 +936,10 @@ e_cal_backend_http_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GList
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
+	gchar *address, *name;
+	icalcomponent *vfb;
+	char *calobj;
+	
 
 	cbhttp = E_CAL_BACKEND_HTTP (backend);
 	priv = cbhttp->priv;
@@ -719,7 +950,29 @@ e_cal_backend_http_get_free_busy (ECalBackendSync *backend, EDataCal *cal, GList
 	if (!priv->cache)
 		return GNOME_Evolution_Calendar_NoSuchCal;
 
-	/* FIXME */
+        if (users == NULL) {
+		if (e_cal_backend_mail_account_get_default (&address, &name)) {
+                        vfb = create_user_free_busy (cbhttp, address, name, start, end);
+                        calobj = icalcomponent_as_ical_string (vfb);
+                        *freebusy = g_list_append (*freebusy, g_strdup (calobj));
+                        icalcomponent_free (vfb);	
+                        g_free (address);
+                        g_free (name);
+		}
+	} else {
+                GList *l;
+                for (l = users; l != NULL; l = l->next ) {
+                        address = l->data;
+                        if (e_cal_backend_mail_account_is_valid (address, &name)) {
+                                vfb = create_user_free_busy (cbhttp, address, name, start, end);
+                                calobj = icalcomponent_as_ical_string (vfb);
+                                *freebusy = g_list_append (*freebusy, g_strdup (calobj));
+                                icalcomponent_free (vfb);
+                                g_free (name);
+                        }
+                }
+	}
+
 	return GNOME_Evolution_Calendar_Success;
 }
 
@@ -768,7 +1021,7 @@ e_cal_backend_http_create_object (ECalBackendSync *backend, EDataCal *cal, char
 
 static ECalBackendSyncStatus
 e_cal_backend_http_modify_object (ECalBackendSync *backend, EDataCal *cal, const char *calobj, 
-				CalObjModType mod, char **old_object)
+				CalObjModType mod, char **old_object, char **new_object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -785,7 +1038,8 @@ e_cal_backend_http_modify_object (ECalBackendSync *backend, EDataCal *cal, const
 static ECalBackendSyncStatus
 e_cal_backend_http_remove_object (ECalBackendSync *backend, EDataCal *cal,
 				const char *uid, const char *rid,
-				CalObjModType mod, char **object)
+				CalObjModType mod, char **old_object,
+				char **object)
 {
 	ECalBackendHttp *cbhttp;
 	ECalBackendHttpPrivate *priv;
@@ -795,6 +1049,8 @@ e_cal_backend_http_remove_object (ECalBackendSync *backend, EDataCal *cal,
 
 	g_return_val_if_fail (uid != NULL, GNOME_Evolution_Calendar_ObjectNotFound);
 
+	*old_object = *object = NULL;
+
 	return GNOME_Evolution_Calendar_PermissionDenied;
 }
 
@@ -875,6 +1131,8 @@ e_cal_backend_http_init (ECalBackendHttp *cbhttp, ECalBackendHttpClass *class)
 	priv->uri = NULL;
 	priv->reload_timeout_id = 0;
 	priv->opened = FALSE;
+
+	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbhttp), TRUE);
 }
 
 /* Class initialization function for the file backend */
