@@ -5,15 +5,15 @@
  * Authors: David Trowbridge <trowbrds@cs.colorado.edu>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -408,21 +408,16 @@ e_cal_backend_weather_get_ldap_attribute (ECalBackendSync *backend, EDataCal *ca
 	return GNOME_Evolution_Calendar_Success;
 }
 
-static char *sc[] = {
-	CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT,
-	CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS,
-	CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS,
-	CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS,
-	CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT,
-	CAL_STATIC_CAPABILITY_NO_THISANDFUTURE,
-	CAL_STATIC_CAPABILITY_NO_THISANDPRIOR,
-	NULL
-};
-
 static ECalBackendSyncStatus
 e_cal_backend_weather_get_static_capabilities (ECalBackendSync *backend, EDataCal *cal, char **capabilities)
 {
-	*capabilities = sc;
+	*capabilities = g_strdup (CAL_STATIC_CAPABILITY_NO_ALARM_REPEAT ","
+				  CAL_STATIC_CAPABILITY_NO_AUDIO_ALARMS  ","
+				  CAL_STATIC_CAPABILITY_NO_DISPLAY_ALARMS  ","
+				  CAL_STATIC_CAPABILITY_NO_PROCEDURE_ALARMS  ","
+				  CAL_STATIC_CAPABILITY_NO_TASK_ASSIGNMENT  ","
+				  CAL_STATIC_CAPABILITY_NO_THISANDFUTURE  ","
+				  CAL_STATIC_CAPABILITY_NO_THISANDPRIOR);
 
 	return GNOME_Evolution_Calendar_Success;
 }
@@ -432,7 +427,7 @@ e_cal_backend_weather_open (ECalBackendSync *backend, EDataCal *cal, gboolean on
 {
 	ECalBackendWeather *cbw;
 	ECalBackendWeatherPrivate *priv;
-	char *uri;
+	const char *uri;
 
 	cbw = E_CAL_BACKEND_WEATHER (backend);
 	priv = cbw->priv;
@@ -829,6 +824,8 @@ e_cal_backend_weather_init (ECalBackendWeather *cbw, ECalBackendWeatherClass *cl
 	priv->city = NULL;
 
 	priv->zones = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, free_zone);
+
+	e_cal_backend_sync_set_lock (E_CAL_BACKEND_SYNC (cbw), TRUE);
 }
 
 /* Class initialization function for the weather backend */
