@@ -9,15 +9,15 @@
  *          Rodrigo Moya <rodrigo@ximian.com>    
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -31,15 +31,6 @@
 
 
 
-/* A category that exists in some of the objects of the calendar */
-typedef struct {
-	/* Category name, also used as the key in the categories hash table */
-	char *name;
-
-	/* Number of objects that have this category */
-	int refcount;
-} ECalBackendCategory;
-
 /* Private part of the CalBackend structure */
 struct _ECalBackendPrivate {
 	/* The source for this backend */
@@ -57,14 +48,6 @@ struct _ECalBackendPrivate {
 
 	GMutex *queries_mutex;
 	EList *queries;
-	
-	/* Hash table of live categories, temporary hash of
-	 * added/removed categories, and idle handler for sending
-	 * category_changed.
-	 */
-	GHashTable *categories;
-	GHashTable *changed_categories;
-	guint category_idle_id;
 
 	/* ECalBackend to pass notifications on to */
 	ECalBackend *notification_proxy;
@@ -91,8 +74,6 @@ static void e_cal_backend_class_init (ECalBackendClass *class);
 static void e_cal_backend_init (ECalBackend *backend);
 static void e_cal_backend_finalize (GObject *object);
 
-static void notify_categories_changed (ECalBackend *backend);
-
 #define CLASS(backend) (E_CAL_BACKEND_CLASS (G_OBJECT_GET_CLASS (backend)))
 
 static GObjectClass *parent_class;
@@ -101,7 +82,6 @@ static GObjectClass *parent_class;
 
 /**
  * e_cal_backend_get_type:
- * @void:
  *
  * Registers the #ECalBackend class if necessary, and returns the type ID
  * associated to it.
@@ -301,29 +281,6 @@ e_cal_backend_init (ECalBackend *backend)
 	/* FIXME bonobo_object_ref/unref? */
 	priv->queries = e_list_new((EListCopyFunc) g_object_ref, (EListFreeFunc) g_object_unref, NULL);
 	priv->queries_mutex = g_mutex_new ();
-	
-	priv->categories = g_hash_table_new (g_str_hash, g_str_equal);
-	priv->changed_categories = g_hash_table_new (g_str_hash, g_str_equal);
-}
-
-/* Used from g_hash_table_foreach(), frees a ECalBackendCategory structure */
-static void
-free_category_cb (gpointer key, gpointer value, gpointer data)
-{
-	ECalBackendCategory *c = value;
-
-	g_free (c->name);
-	g_free (c);
-}
-
-static gboolean
-prune_changed_categories (gpointer key, gpointer value, gpointer data)
-{
-	ECalBackendCategory *c = value;
-
-	if (!c->refcount)
-		free_category_cb (key, value, data);
-	return TRUE;
 }
 
 void
@@ -338,18 +295,9 @@ e_cal_backend_finalize (GObject *object)
 
 	g_object_unref (priv->queries);
 
-	g_hash_table_foreach_remove (priv->changed_categories, prune_changed_categories, NULL);
-	g_hash_table_destroy (priv->changed_categories);
-
-	g_hash_table_foreach (priv->categories, free_category_cb, NULL);
-	g_hash_table_destroy (priv->categories);
-
 	g_mutex_free (priv->clients_mutex);
 	g_mutex_free (priv->queries_mutex);
 
-	if (priv->category_idle_id)
-		g_source_remove (priv->category_idle_id);
-
 	g_free (priv);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
@@ -357,6 +305,14 @@ e_cal_backend_finalize (GObject *object)
 
 
 
+/**
+ * e_cal_backend_get_source:
+ * @backend: An #ECalBackend object.
+ *
+ * Gets the #ESource associated with the given backend.
+ *
+ * Return value: The #ESource for the backend.
+ */
 ESource *
 e_cal_backend_get_source (ECalBackend *backend)
 {
@@ -392,6 +348,14 @@ e_cal_backend_get_uri (ECalBackend *backend)
 	return priv->uri;
 }
 
+/**
+ * e_cal_backend_get_kind:
+ * @backend: An #ECalBackend object.
+ *
+ * Gets the kind of components the given backend stores.
+ *
+ * Return value: The kind of components for this backend.
+ */
 icalcomponent_kind
 e_cal_backend_get_kind (ECalBackend *backend)
 {
@@ -427,6 +391,14 @@ last_client_gone (ECalBackend *backend)
 	g_signal_emit (backend, e_cal_backend_signals[LAST_CLIENT_GONE], 0);
 }
 
+/**
+ * e_cal_backend_add_client:
+ * @backend: An ECalBackend object.
+ * @cal: An EDataCal object.
+ *
+ * Adds a new client to the given backend. For any event, the backend will
+ * notify all clients added via this function.
+ */
 void
 e_cal_backend_add_client (ECalBackend *backend, EDataCal *cal)
 {
@@ -448,14 +420,15 @@ e_cal_backend_add_client (ECalBackend *backend, EDataCal *cal)
 	g_mutex_lock (priv->clients_mutex);
 	priv->clients = g_list_append (priv->clients, cal);
 	g_mutex_unlock (priv->clients_mutex);
-
-	/* Tell the new client about the list of categories.
-	 * (Ends up telling all the other clients too, but *shrug*.)
-	 */
-	/* FIXME This doesn't seem right at all */
-	notify_categories_changed (backend);
 }
 
+/**
+ * e_cal_backend_remove_client:
+ * @backend: An #ECalBackend object.
+ * @cal: An #EDataCal object.
+ *
+ * Removes a client from the list of connected clients to the given backend.
+ */
 void
 e_cal_backend_remove_client (ECalBackend *backend, EDataCal *cal)
 {
@@ -483,6 +456,15 @@ e_cal_backend_remove_client (ECalBackend *backend, EDataCal *cal)
 		last_client_gone (backend);
 }
 
+/**
+ * e_cal_backend_add_query:
+ * @backend: An #ECalBackend object.
+ * @query: An #EDataCalView object.
+ *
+ * Adds a query to the list of live queries being run by the given backend.
+ * Doing so means that any listener on the query will get notified of any
+ * change that affect the live query.
+ */
 void
 e_cal_backend_add_query (ECalBackend *backend, EDataCalView *query)
 {
@@ -496,6 +478,14 @@ e_cal_backend_add_query (ECalBackend *backend, EDataCalView *query)
 	g_mutex_unlock (backend->priv->queries_mutex);
 }
 
+/**
+ * e_cal_backend_get_queries:
+ * @backend: An #ECalBackend object.
+ *
+ * Gets the list of live queries being run on the given backend.
+ *
+ * Return value: The list of live queries.
+ */
 EList *
 e_cal_backend_get_queries (ECalBackend *backend)
 {
@@ -512,8 +502,6 @@ e_cal_backend_get_queries (ECalBackend *backend)
  *
  * Queries the cal address associated with a calendar backend, which
  * must already have an open calendar.
- *
- * Return value: The cal address associated with the calendar.
  **/
 void
 e_cal_backend_get_cal_address (ECalBackend *backend, EDataCal *cal)
@@ -525,6 +513,41 @@ e_cal_backend_get_cal_address (ECalBackend *backend, EDataCal *cal)
 	(* CLASS (backend)->get_cal_address) (backend, cal);
 }
 
+void
+e_cal_backend_notify_readonly (ECalBackend *backend, gboolean read_only)
+{
+	ECalBackendPrivate *priv;
+	GList *l;
+
+	priv = backend->priv;
+
+	if (priv->notification_proxy) {
+		e_cal_backend_notify_readonly (priv->notification_proxy, read_only);
+		return;
+	}
+	for (l = priv->clients; l; l = l->next)
+		e_data_cal_notify_read_only (l->data, GNOME_Evolution_Calendar_Success, read_only);
+}
+
+void
+e_cal_backend_notify_cal_address (ECalBackend *backend, char *address)
+{
+	ECalBackendPrivate *priv;
+	GList *l;
+
+	priv = backend->priv;
+
+	for (l = priv->clients; l; l = l->next)
+		e_data_cal_notify_cal_address (l->data, GNOME_Evolution_Calendar_Success, address);
+}
+
+/**
+ * e_cal_backend_get_alarm_email_address:
+ * @backend: An #ECalBackend object.
+ * @cal: An #EDataCal object.
+ *
+ * Calls the get_alarm_email_address method on the given backend.
+ */
 void
 e_cal_backend_get_alarm_email_address (ECalBackend *backend, EDataCal *cal)
 {
@@ -535,6 +558,13 @@ e_cal_backend_get_alarm_email_address (ECalBackend *backend, EDataCal *cal)
 	(* CLASS (backend)->get_alarm_email_address) (backend, cal);
 }
 
+/**
+ *e_cal_backend_get_alarm_email_address:
+ * @backend: An #ECalBackend object.
+ * @cal: An #EDataCal object.
+ *
+ * Calls the get_ldap_attribute method of the given backend.
+ */
 void
 e_cal_backend_get_ldap_attribute (ECalBackend *backend, EDataCal *cal)
 {
@@ -545,6 +575,13 @@ e_cal_backend_get_ldap_attribute (ECalBackend *backend, EDataCal *cal)
 	(* CLASS (backend)->get_ldap_attribute) (backend, cal);
 }
 
+/**
+ * e_cal_backend_get_alarm_email_address:
+ * @backend: An #ECalBackend object.
+ * @cal: An #EDataCal object.
+ *
+ * Calls the get_static_capabilities method on the given backend.
+ */
 void
 e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal)
 {
@@ -558,7 +595,7 @@ e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal)
 /**
  * e_cal_backend_open:
  * @backend: A calendar backend.
- * @uristr: URI that contains the calendar data.
+ * @cal: An #EDataCal object.
  * @only_if_exists: Whether the calendar should be opened only if it already
  * exists.  If FALSE, a new calendar will be created when the specified @uri
  * does not exist.
@@ -567,9 +604,7 @@ e_cal_backend_get_static_capabilities (ECalBackend *backend, EDataCal *cal)
  *
  * Opens a calendar backend with data from a calendar stored at the specified
  * URI.
- *
- * Return value: An operation status code.
- **/
+ */
 void
 e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists,
 		    const char *username, const char *password)
@@ -581,6 +616,13 @@ e_cal_backend_open (ECalBackend *backend, EDataCal *cal, gboolean only_if_exists
 	(* CLASS (backend)->open) (backend, cal, only_if_exists, username, password);
 }
 
+/**
+ * e_cal_backend_remove:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ *
+ * Removes the calendar being accessed by the given backend.
+ */
 void
 e_cal_backend_remove (ECalBackend *backend, EDataCal *cal)
 {
@@ -599,7 +641,7 @@ e_cal_backend_remove (ECalBackend *backend, EDataCal *cal)
  * 
  * Return value: TRUE if the backend has been loaded with data, FALSE
  * otherwise.
- **/
+ */
 gboolean
 e_cal_backend_is_loaded (ECalBackend *backend)
 {
@@ -617,10 +659,10 @@ e_cal_backend_is_loaded (ECalBackend *backend)
 /**
  * e_cal_backend_is_read_only
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  *
  * Queries whether a calendar backend is read only or not.
  *
- * Return value: TRUE if the calendar is read only, FALSE otherwise.
  */
 void
 e_cal_backend_is_read_only (ECalBackend *backend, EDataCal *cal)
@@ -632,6 +674,13 @@ e_cal_backend_is_read_only (ECalBackend *backend, EDataCal *cal)
 	(* CLASS (backend)->is_read_only) (backend, cal);
 }
 
+/**
+ * e_cal_backend_start_query:
+ * @backend: A calendar backend.
+ * @query: The query to be started.
+ *
+ * Starts a new live query on the given backend.
+ */
 void 
 e_cal_backend_start_query (ECalBackend *backend, EDataCalView *query)
 {
@@ -670,9 +719,8 @@ e_cal_backend_get_mode (ECalBackend *backend)
  * @backend: A calendar backend
  * @mode: Mode to change to
  * 
- * Sets the mode of the calendar
- * 
- **/
+ * Sets the mode of the calendar 
+ */
 void
 e_cal_backend_set_mode (ECalBackend *backend, CalMode mode)
 {
@@ -683,6 +731,13 @@ e_cal_backend_set_mode (ECalBackend *backend, CalMode mode)
 	(* CLASS (backend)->set_mode) (backend, mode);
 }
 
+/**
+ * e_cal_backend_get_default_object:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ *
+ * Calls the get_default_object method on the given backend.
+ */
 void
 e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal)
 {
@@ -696,15 +751,13 @@ e_cal_backend_get_default_object (ECalBackend *backend, EDataCal *cal)
 /**
  * e_cal_backend_get_object:
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @uid: Unique identifier for a calendar object.
  * @rid: ID for the object's recurrence to get.
  *
  * Queries a calendar backend for a calendar object based on its unique
  * identifier and its recurrence ID (if a recurrent appointment).
- *
- * Return value: The string representation of a complete calendar wrapping the
- * the sought object, or NULL if no object had the specified UID.
- **/
+ */
 void
 e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
 {
@@ -718,13 +771,12 @@ e_cal_backend_get_object (ECalBackend *backend, EDataCal *cal, const char *uid,
 
 /**
  * e_cal_backend_get_object_list:
- * @backend: 
- * @type: 
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @sexp: Expression to search for.
  * 
- * 
- * 
- * Return value: 
- **/
+ * Calls the get_object_list method on the given backend.
+ */
 void
 e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *sexp)
 {
@@ -732,20 +784,40 @@ e_cal_backend_get_object_list (ECalBackend *backend, EDataCal *cal, const char *
 	g_return_if_fail (E_IS_CAL_BACKEND (backend));
 
 	g_assert (CLASS (backend)->get_object_list != NULL);
-	return (* CLASS (backend)->get_object_list) (backend, cal, sexp);
+	(* CLASS (backend)->get_object_list) (backend, cal, sexp);
+}
+
+/**
+ * e_cal_backend_get_attachment_list:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @uid: Unique identifier for a calendar object.
+ * @rid: ID for the object's recurrence to get.
+ *
+ * Queries a calendar backend for attachments present in a calendar object based 
+ * on its unique identifier and its recurrence ID (if a recurrent appointment).
+ */
+void
+e_cal_backend_get_attachment_list (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid)
+{
+	g_return_if_fail (backend != NULL);
+	g_return_if_fail (E_IS_CAL_BACKEND (backend));
+	g_return_if_fail (uid != NULL);
+
+	g_assert (CLASS (backend)->get_object != NULL);
+	(* CLASS (backend)->get_attachment_list) (backend, cal, uid, rid);
 }
 
 /**
  * e_cal_backend_get_free_busy:
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @users: List of users to get free/busy information for.
  * @start: Start time for query.
  * @end: End time for query.
  * 
  * Gets a free/busy object for the given time interval
- * 
- * Return value: a list of CalObj's
- **/
+ */
 void
 e_cal_backend_get_free_busy (ECalBackend *backend, EDataCal *cal, GList *users, time_t start, time_t end)
 {
@@ -760,14 +832,13 @@ e_cal_backend_get_free_busy (ECalBackend *backend, EDataCal *cal, GList *users,
 
 /**
  * e_cal_backend_get_changes:
- * @backend: A calendar backend
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @change_id: A unique uid for the callers change list
  * 
  * Builds a sequence of objects and the type of change that occurred on them since
  * the last time the give change_id was seen
- * 
- * Return value: A list of the objects that changed and the type of change
- **/
+ */
 void
 e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *change_id) 
 {
@@ -782,13 +853,13 @@ e_cal_backend_get_changes (ECalBackend *backend, EDataCal *cal, const char *chan
 /**
  * e_cal_backend_discard_alarm
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @uid: UID of the component to discard the alarm from.
  * @auid: Alarm ID.
  *
  * Discards an alarm from the given component. This allows the specific backend
  * to do whatever is needed to really discard the alarm.
- *
- **/
+ */
 void
 e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const char *uid, const char *auid)
 {
@@ -801,6 +872,14 @@ e_cal_backend_discard_alarm (ECalBackend *backend, EDataCal *cal, const char *ui
 	(* CLASS (backend)->discard_alarm) (backend, cal, uid, auid);
 }
 
+/**
+ * e_cal_backend_create_object:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @calobj: The object to create.
+ *
+ * Calls the create_object method on the given backend.
+ */
 void
 e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *calobj)
 {
@@ -814,6 +893,15 @@ e_cal_backend_create_object (ECalBackend *backend, EDataCal *cal, const char *ca
 		e_data_cal_notify_object_created (cal, GNOME_Evolution_Calendar_PermissionDenied, NULL, NULL);
 }
 
+/**
+ * e_cal_backend_modify_object:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @calobj: Object to be modified.
+ * @mod: Type of modification.
+ *
+ * Calls the modify_object method on the given backend.
+ */
 void
 e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *calobj, CalObjModType mod)
 {
@@ -830,13 +918,14 @@ e_cal_backend_modify_object (ECalBackend *backend, EDataCal *cal, const char *ca
 /**
  * e_cal_backend_remove_object:
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @uid: Unique identifier of the object to remove.
  * @rid: A recurrence ID.
+ * @mod: Type of removal.
  * 
  * Removes an object in a calendar backend.  The backend will notify all of its
  * clients about the change.
- * 
- **/
+ */
 void
 e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *uid, const char *rid, CalObjModType mod)
 {
@@ -848,6 +937,14 @@ e_cal_backend_remove_object (ECalBackend *backend, EDataCal *cal, const char *ui
 	(* CLASS (backend)->remove_object) (backend, cal, uid, rid, mod);
 }
 
+/**
+ * e_cal_backend_receive_objects:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @calobj: iCalendar object.
+ *
+ * Calls the receive_objects method on the given backend.
+ */
 void
 e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
 {
@@ -859,6 +956,14 @@ e_cal_backend_receive_objects (ECalBackend *backend, EDataCal *cal, const char *
 	(* CLASS (backend)->receive_objects) (backend, cal, calobj);
 }
 
+/**
+ * e_cal_backend_send_objects:
+ * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
+ * @calobj: iCalendar object to be sent.
+ *
+ * Calls the send_objects method on the given backend.
+ */
 void
 e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *calobj)
 {
@@ -873,14 +978,13 @@ e_cal_backend_send_objects (ECalBackend *backend, EDataCal *cal, const char *cal
 /**
  * e_cal_backend_get_timezone:
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @tzid: Unique identifier of a VTIMEZONE object. Note that this must not be
  * NULL.
  * 
  * Returns the icaltimezone* corresponding to the TZID, or NULL if the TZID
  * can't be found.
- * 
- * Returns: The icaltimezone* corresponding to the given TZID, or NULL.
- **/
+ */
 void
 e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
 {
@@ -895,14 +999,12 @@ e_cal_backend_get_timezone (ECalBackend *backend, EDataCal *cal, const char *tzi
 /**
  * e_cal_backend_set_default_timezone:
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @tzid: The TZID identifying the timezone.
  * 
  * Sets the default timezone for the calendar, which is used to resolve
- * DATE and floating DATE-TIME values.
- * 
- * Returns: TRUE if the VTIMEZONE data for the timezone was found, or FALSE if
- * not.
- **/
+ * DATE and floating DATE-TIME values. 
+ */
 void
 e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const char *tzid)
 {
@@ -917,11 +1019,10 @@ e_cal_backend_set_default_timezone (ECalBackend *backend, EDataCal *cal, const c
 /**
  * e_cal_backend_add_timezone
  * @backend: A calendar backend.
+ * @cal: An #EDataCal object.
  * @tzobj: The timezone object, in a string.
  *
  * Add a timezone object to the given backend.
- *
- * Returns: TRUE if successful, or FALSE if not.
  */
 void
 e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, const char *tzobj)
@@ -933,6 +1034,12 @@ e_cal_backend_add_timezone (ECalBackend *backend, EDataCal *cal, const char *tzo
 	(* CLASS (backend)->add_timezone) (backend, cal, tzobj);
 }
 
+/**
+ * e_cal_backend_internal_get_default_timezone:
+ * @backend: A calendar backend.
+ *
+ * Calls the internal_get_default_timezone method on the given backend.
+ */
 icaltimezone *
 e_cal_backend_internal_get_default_timezone (ECalBackend *backend)
 {
@@ -942,6 +1049,13 @@ e_cal_backend_internal_get_default_timezone (ECalBackend *backend)
 	return (* CLASS (backend)->internal_get_default_timezone) (backend);
 }
 
+/**
+ * e_cal_backend_internal_get_timezone:
+ * @backend: A calendar backend.
+ * @tzid: ID of the timezone to get.
+ *
+ * Calls the internal_get_timezone method on the given backend.
+ */
 icaltimezone *
 e_cal_backend_internal_get_timezone (ECalBackend *backend, const char *tzid)
 {
@@ -952,6 +1066,13 @@ e_cal_backend_internal_get_timezone (ECalBackend *backend, const char *tzid)
 	return (* CLASS (backend)->internal_get_timezone) (backend, tzid);
 }
 
+/**
+ * e_cal_backend_set_notification_proxy:
+ * @backend: A calendar backend.
+ * @proxy: The calendar backend to act as notification proxy.
+ *
+ * Sets the backend that will act as notification proxy for the given backend.
+ */
 void
 e_cal_backend_set_notification_proxy (ECalBackend *backend, ECalBackend *proxy)
 {
@@ -971,9 +1092,9 @@ e_cal_backend_set_notification_proxy (ECalBackend *backend, ECalBackend *proxy)
  *
  * Notifies each of the backend's listeners about a new object.
  *
- * cal_notify_object_created() calls this for you. You only need to
+ * #e_data_cal_notify_object_created() calls this for you. You only need to
  * call e_cal_backend_notify_object_created() yourself to report objects
- * created by non-PCS clients.
+ * created by non-EDS clients.
  **/
 void
 e_cal_backend_notify_object_created (ECalBackend *backend, const char *calobj)
@@ -1028,6 +1149,85 @@ match_query_and_notify (EDataCalView *query, const char *old_object, const char
 	}
 }
 
+/**
+ * e_cal_backend_notify_view_progress:
+ * @backend: A calendar backend.
+ * @message: the UID of the removed object
+ * @percent: percentage of the objects loaded in the view
+ *
+ * Notifies each of the backend's listeners about the view_progress in downloading the items.
+ **/
+void
+e_cal_backend_notify_view_progress (ECalBackend *backend, const char *message, int percent)
+{
+	ECalBackendPrivate *priv;
+	EList *queries;
+	EIterator *iter;
+	EDataCalView *query;
+
+	priv = backend->priv;
+
+	if (priv->notification_proxy) {
+		e_cal_backend_notify_view_progress (priv->notification_proxy, message, percent);
+		return;
+	}
+
+	queries = e_cal_backend_get_queries (backend);
+	iter = e_list_get_iterator (queries);
+
+	while (e_iterator_is_valid (iter)) {
+		query = QUERY (e_iterator_get (iter));
+
+		bonobo_object_ref (query);
+
+		e_data_cal_view_notify_progress (query, message, percent);
+
+		bonobo_object_unref (query);
+
+		e_iterator_next (iter);
+	}
+	g_object_unref (iter);
+}
+
+/**
+ * e_cal_backend_notify_view_done:
+ * @backend: A calendar backend.
+ * @status: returns the status once the view is fully populated.
+ *
+ * Notifies each of the backend's listeners about the view_done in downloading the items.
+ **/
+void
+e_cal_backend_notify_view_done (ECalBackend *backend, GNOME_Evolution_Calendar_CallStatus status)
+{
+	ECalBackendPrivate *priv;
+	EList *queries;
+	EIterator *iter;
+	EDataCalView *query;
+
+	priv = backend->priv;
+
+	if (priv->notification_proxy) {
+		e_cal_backend_notify_view_done (priv->notification_proxy, status);
+		return;
+	}
+
+	queries = e_cal_backend_get_queries (backend);
+	iter = e_list_get_iterator (queries);
+
+	while (e_iterator_is_valid (iter)) {
+		query = QUERY (e_iterator_get (iter));
+
+		bonobo_object_ref (query);
+
+		e_data_cal_view_notify_done (query, status);
+
+		bonobo_object_unref (query);
+
+		e_iterator_next (iter);
+	}
+	g_object_unref (iter);
+}
+
 /**
  * e_cal_backend_notify_object_modified:
  * @backend: A calendar backend.
@@ -1036,9 +1236,9 @@ match_query_and_notify (EDataCalView *query, const char *old_object, const char
  *
  * Notifies each of the backend's listeners about a modified object.
  *
- * cal_notify_object_modified() calls this for you. You only need to
+ * #e_data_cal_notify_object_modified() calls this for you. You only need to
  * call e_cal_backend_notify_object_modified() yourself to report objects
- * modified by non-PCS clients.
+ * modified by non-EDS clients.
  **/
 void
 e_cal_backend_notify_object_modified (ECalBackend *backend, 
@@ -1082,9 +1282,9 @@ e_cal_backend_notify_object_modified (ECalBackend *backend,
  *
  * Notifies each of the backend's listeners about a removed object.
  *
- * cal_notify_object_removed() calls this for you. You only need to
+ * e_data_cal_notify_object_removed() calls this for you. You only need to
  * call e_cal_backend_notify_object_removed() yourself to report objects
- * removed by non-PCS clients.
+ * removed by non-EDS clients.
  **/
 void
 e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
@@ -1136,8 +1336,8 @@ e_cal_backend_notify_object_removed (ECalBackend *backend, const char *uid,
  **/
 void
 e_cal_backend_notify_mode (ECalBackend *backend,
-			 GNOME_Evolution_Calendar_CalListener_SetModeStatus status, 
-			 GNOME_Evolution_Calendar_CalMode mode)
+			   GNOME_Evolution_Calendar_CalListener_SetModeStatus status, 
+			   GNOME_Evolution_Calendar_CalMode mode)
 {
 	ECalBackendPrivate *priv = backend->priv;
 	GList *l;
@@ -1151,6 +1351,13 @@ e_cal_backend_notify_mode (ECalBackend *backend,
 		e_data_cal_notify_mode (l->data, status, mode);
 }
 
+/**
+ * e_cal_backend_notify_auth_required:
+ * @backend: A calendar backend.
+ *
+ * Notifies each of the backend's listeners that authentication is required to
+ * open the calendar.
+ */
 void
 e_cal_backend_notify_auth_required (ECalBackend *backend)
 {
@@ -1182,144 +1389,3 @@ e_cal_backend_notify_error (ECalBackend *backend, const char *message)
 	for (l = priv->clients; l; l = l->next)
 		e_data_cal_notify_error (l->data, message);
 }
-
-static void
-add_category_cb (gpointer name, gpointer category, gpointer data)
-{
-	GNOME_Evolution_Calendar_StringSeq *seq = data;
-
-	seq->_buffer[seq->_length++] = CORBA_string_dup (name);
-}
-
-static void
-notify_categories_changed (ECalBackend *backend)
-{
-	ECalBackendPrivate *priv = backend->priv;
-	GNOME_Evolution_Calendar_StringSeq *seq;
-	GList *l;
-
-	/* Build the sequence of category names */
-	seq = GNOME_Evolution_Calendar_StringSeq__alloc ();
-	seq->_length = 0;
-	seq->_maximum = g_hash_table_size (priv->categories);
-	seq->_buffer = CORBA_sequence_CORBA_string_allocbuf (seq->_maximum);
-	CORBA_sequence_set_release (seq, TRUE);
-
-	g_hash_table_foreach (priv->categories, add_category_cb, seq);
-
-	/* Notify the clients */
-	for (l = priv->clients; l; l = l->next)
-		e_data_cal_notify_categories_changed (l->data, seq);
-
-	CORBA_free (seq);
-}
-
-static gboolean
-idle_notify_categories_changed (gpointer data)
-{
-	ECalBackend *backend = E_CAL_BACKEND (data);
-	ECalBackendPrivate *priv = backend->priv;
-
-	if (g_hash_table_size (priv->changed_categories)) {
-		notify_categories_changed (backend);
-		g_hash_table_foreach_remove (priv->changed_categories, prune_changed_categories, NULL);
-	}
-
-	priv->category_idle_id = 0;
-	
-	return FALSE;
-}
-
-/**
- * e_cal_backend_ref_categories:
- * @backend: A calendar backend
- * @categories: a list of categories
- *
- * Adds 1 to the refcount of each of the named categories. If any of
- * the categories are new, clients will be notified of the updated
- * category list at idle time.
- **/
-void
-e_cal_backend_ref_categories (ECalBackend *backend, GSList *categories)
-{
-	ECalBackendPrivate *priv;
-	ECalBackendCategory *c;
-	const char *name;
-
-	priv = backend->priv;
-
-	while (categories) {
-		name = categories->data;
-		c = g_hash_table_lookup (priv->categories, name);
-
-		if (c)
-			c->refcount++;
-		else {
-			/* See if it was recently removed */
-
-			c = g_hash_table_lookup (priv->changed_categories, name);
-			if (c && c->refcount == 0) {
-				/* Move it back to the set of live categories */
-				g_hash_table_remove (priv->changed_categories, c->name);
-
-				c->refcount = 1;
-				g_hash_table_insert (priv->categories, c->name, c);
-			} else {
-				/* Create a new category */
-				c = g_new (ECalBackendCategory, 1);
-				c->name = g_strdup (name);
-				c->refcount = 1;
-				g_hash_table_insert (priv->categories, c->name, c);
-				g_hash_table_insert (priv->changed_categories, c->name, c);
-			}
-		}
-
-		categories = categories->next;
-	}
-
-	if (g_hash_table_size (priv->changed_categories) &&
-	    !priv->category_idle_id)
-		priv->category_idle_id = g_idle_add (idle_notify_categories_changed, backend);
-}
-
-/**
- * e_cal_backend_unref_categories:
- * @backend: A calendar backend
- * @categories: a list of categories
- *
- * Subtracts 1 from the refcount of each of the named categories. If
- * any of the refcounts go down to 0, clients will be notified of the
- * updated category list at idle time.
- **/
-void
-e_cal_backend_unref_categories (ECalBackend *backend, GSList *categories)
-{
-	ECalBackendPrivate *priv;
-	ECalBackendCategory *c;
-	const char *name;
-
-	priv = backend->priv;
-
-	while (categories) {
-		name = categories->data;
-		c = g_hash_table_lookup (priv->categories, name);
-
-		if (c) {
-			g_assert (c != NULL);
-			g_assert (c->refcount > 0);
-
-			c->refcount--;
-
-			if (c->refcount == 0) {
-				g_hash_table_remove (priv->categories, c->name);
-				g_hash_table_insert (priv->changed_categories, c->name, c);
-			}
-		}
-
-		categories = categories->next;
-	}
-
-	if (g_hash_table_size (priv->changed_categories) &&
-	    !priv->category_idle_id)
-		priv->category_idle_id = g_idle_add (idle_notify_categories_changed, backend);
-}
