@@ -7,15 +7,15 @@
  *   JP Rosevear <jpr@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
@@ -25,6 +25,7 @@
 #include <bonobo/bonobo-main.h>
 #include <libedataserver/e-url.h>
 #include <libedataserver/e-source.h>
+#include <libedataserver/e-data-server-module.h>
 #include "e-cal-backend.h"
 #include "e-data-cal.h"
 #include "e-data-cal-factory.h"
@@ -47,6 +48,9 @@ struct _EDataCalFactoryPrivate {
 
 	/* Whether we have been registered with OAF yet */
 	guint registered : 1;
+        
+        int mode;
+        
 };
 
 /* Signal IDs */
@@ -74,19 +78,19 @@ calobjtype_to_icalkind (const GNOME_Evolution_Calendar_CalObjType type)
 	return ICAL_NO_COMPONENT;
 }
 
-static GType
-get_backend_type (GHashTable *methods, const char *method, icalcomponent_kind kind)
+static ECalBackendFactory*
+get_backend_factory (GHashTable *methods, const char *method, icalcomponent_kind kind)
 {
 	GHashTable *kinds;
-	GType type;
+	ECalBackendFactory *factory;
 	
 	kinds = g_hash_table_lookup (methods, method);
 	if (!kinds)
 		return 0;
 
-	type = (GType) (g_hash_table_lookup (kinds, GINT_TO_POINTER (kind)));
+	factory = g_hash_table_lookup (kinds, GINT_TO_POINTER (kind));
 
-	return type;
+	return factory;
 }
 
 /* Looks up a calendar backend in a factory's hash table of uri->cal.  If
@@ -166,7 +170,7 @@ impl_CalFactory_getCal (PortableServer_Servant servant,
 	ECalBackend *backend;
 	CORBA_Environment ev2;
 	GNOME_Evolution_Calendar_CalListener listener_copy;
-	GType backend_type;
+	ECalBackendFactory *backend_factory;
 	ESource *source;
 	char *str_uri;
 	EUri *uri;
@@ -193,20 +197,18 @@ impl_CalFactory_getCal (PortableServer_Servant servant,
 
 	/* Parse the uri */
 	uri = e_uri_new (str_uri);
-	g_free (str_uri);
-
 	if (!uri) {
 		bonobo_exception_set (ev, ex_GNOME_Evolution_Calendar_CalFactory_InvalidURI);
 
 		return CORBA_OBJECT_NIL;
 	}
-	str_uri = e_uri_to_string(uri, FALSE);
+
 	uri_type_string = g_strdup_printf ("%s:%d", str_uri, (int)calobjtype_to_icalkind (type));
 	g_free(str_uri);
 
-	/* Find the associated backend type (if any) */
-	backend_type = get_backend_type (priv->methods, uri->protocol, calobjtype_to_icalkind (type));
-	if (!backend_type) {
+	/* Find the associated backend factory (if any) */
+	backend_factory = get_backend_factory (priv->methods, uri->protocol, calobjtype_to_icalkind (type));
+	if (!backend_factory) {
 		/* FIXME Distinguish between method and kind failures? */
 		bonobo_exception_set (ev, ex_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod);
 		goto cleanup;
@@ -228,7 +230,8 @@ impl_CalFactory_getCal (PortableServer_Servant servant,
 	backend = lookup_backend (factory, uri_type_string);
 	if (!backend) {
 		/* There was no existing backend, create a new one */
-		backend = g_object_new (backend_type, "source", source, "kind", calobjtype_to_icalkind (type), NULL);
+		backend = e_cal_backend_factory_new_backend (backend_factory, source);
+
 		if (!backend) {
 			g_warning (G_STRLOC ": could not instantiate backend");
 			bonobo_exception_set (ev, ex_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod);
@@ -244,7 +247,8 @@ impl_CalFactory_getCal (PortableServer_Servant servant,
 	}
 	
 	/* Create the corba calendar */
-	cal = e_data_cal_new (backend, uri_type_string, listener);
+	cal = e_data_cal_new (backend, listener);
+	printf ("cal = %p\n", cal);
 	if (!cal) {
 		g_warning (G_STRLOC ": could not create the corba calendar");
 		bonobo_exception_set (ev, ex_GNOME_Evolution_Calendar_CalFactory_UnsupportedMethod);
@@ -253,6 +257,7 @@ impl_CalFactory_getCal (PortableServer_Servant servant,
 
 	/* Let the backend know about its clients corba clients */
 	e_cal_backend_add_client (backend, cal);
+	e_cal_backend_set_mode (backend, priv->mode);
 	
  cleanup:
 	e_uri_free (uri);
@@ -343,6 +348,32 @@ e_data_cal_factory_class_init (EDataCalFactoryClass *klass)
 	epv->getCal = impl_CalFactory_getCal;
 }
 
+static void 
+set_backend_online_status (gpointer key, gpointer value, gpointer data)
+{
+	ECalBackend *backend = E_CAL_BACKEND (value);
+
+	e_cal_backend_set_mode (backend,  GPOINTER_TO_INT (data));
+}
+
+/**
+ * e_data_cal_factory_set_backend_mode:
+ * @factory: A calendar factory.
+ * @mode: Online mode to set.
+ *
+ * Sets the online mode for all backends created by the given factory.
+ */
+void 
+e_data_cal_factory_set_backend_mode (EDataCalFactory *factory, int mode)
+{
+	EDataCalFactoryPrivate *priv = factory->priv;
+	
+	
+	priv->mode = mode;
+	g_hash_table_foreach (priv->backends, set_backend_online_status, GINT_TO_POINTER (priv->mode));
+}
+
+
 /* Object initialization function for the calendar factory */
 static void
 e_data_cal_factory_init (EDataCalFactory *factory, EDataCalFactoryClass *klass)
@@ -422,37 +453,38 @@ e_data_cal_factory_register_storage (EDataCalFactory *factory, const char *iid)
 }
 
 /**
- * e_data_cal_factory_register_method:
+ * e_data_cal_factory_register_backend:
  * @factory: A calendar factory.
- * @method: Method for the URI, i.e. "http", "file", etc.
- * @backend_type: Class type of the backend to create for this @method.
+ * @backend_factory: The object responsible for creating backends.
  * 
- * Registers the type of a #ECalBackend subclass that will be used to handle URIs
- * with a particular method.  When the factory is asked to open a particular
- * URI, it will look in its list of registered methods and create a backend of
- * the appropriate type.
+ * Registers an #ECalBackend subclass that will be used to handle URIs
+ * with a particular method.  When the factory is asked to open a
+ * particular URI, it will look in its list of registered methods and
+ * create a backend of the appropriate type.
  **/
 void
-e_data_cal_factory_register_method (EDataCalFactory *factory, const char *method, icalcomponent_kind kind, GType backend_type)
+e_data_cal_factory_register_backend (EDataCalFactory *factory, ECalBackendFactory *backend_factory)
 {
 	EDataCalFactoryPrivate *priv;
+	const char *method;
 	char *method_str;
 	GHashTable *kinds;
 	GType type;
-	
-	g_return_if_fail (factory != NULL);
-	g_return_if_fail (E_IS_DATA_CAL_FACTORY (factory));
-	g_return_if_fail (method != NULL);
-	g_return_if_fail (backend_type != 0);
-	g_return_if_fail (g_type_is_a (backend_type, E_TYPE_CAL_BACKEND));
+	icalcomponent_kind kind;
+
+	g_return_if_fail (factory && E_IS_DATA_CAL_FACTORY (factory));
+	g_return_if_fail (backend_factory && E_IS_CAL_BACKEND_FACTORY (backend_factory));
 
 	priv = factory->priv;
 
+	method = E_CAL_BACKEND_FACTORY_GET_CLASS (backend_factory)->get_protocol (backend_factory);
+	kind = E_CAL_BACKEND_FACTORY_GET_CLASS (backend_factory)->get_kind (backend_factory);
+
 	method_str = g_ascii_strdown (method, -1);
 
 	kinds = g_hash_table_lookup (priv->methods, method_str);
 	if (kinds) {
-		type = (GType) (g_hash_table_lookup (kinds, GINT_TO_POINTER (kind)));
+		type = GPOINTER_TO_INT (g_hash_table_lookup (kinds, GINT_TO_POINTER (kind)));
 		if (type) {
 			g_warning (G_STRLOC ": method `%s' already registered", method_str);
 			g_free (method_str);
@@ -466,7 +498,28 @@ e_data_cal_factory_register_method (EDataCalFactory *factory, const char *method
 		g_hash_table_insert (priv->methods, method_str, kinds);
 	}
 	
-	g_hash_table_insert (kinds, GINT_TO_POINTER (kind), (gpointer) backend_type);
+	g_hash_table_insert (kinds, GINT_TO_POINTER (kind), backend_factory);
+}
+
+/**
+ * e_data_cal_factory_register_backends:
+ * @cal_factory: A calendar factory.
+ *
+ * Register all backends for the given factory.
+ */
+void
+e_data_cal_factory_register_backends (EDataCalFactory *cal_factory)
+{
+	GList *factories, *f;
+
+	factories = e_data_server_get_extensions_for_type (E_TYPE_CAL_BACKEND_FACTORY);
+	for (f = factories; f; f = f->next) {
+		ECalBackendFactory *backend_factory = f->data;
+
+		e_data_cal_factory_register_backend (cal_factory, g_object_ref (backend_factory));
+	}
+
+	e_data_server_extension_list_free (factories);
 }
 
 /**
@@ -501,8 +554,15 @@ dump_backend (gpointer key, gpointer value, gpointer data)
 	g_message ("  %s: %p", uri, backend);
 }
 
+/**
+ * e_data_cal_factory_dump_active_backends:
+ * @factory: A calendar factory.
+ *
+ * Dumps to standard output a list of all active backends for the given
+ * factory.
+ */
 void
-e_data_cal_factory_dump_active_backends   (EDataCalFactory *factory)
+e_data_cal_factory_dump_active_backends (EDataCalFactory *factory)
 {
 	EDataCalFactoryPrivate *priv;
 
