@@ -5,7 +5,7 @@
  *  Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
@@ -28,7 +28,6 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/uio.h>
 #include <unistd.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -1338,7 +1337,7 @@ camel_text_index_validate(CamelTextIndex *idx)
 				printf("Warning, read failed for word '%s', at data '%d'\n", word, data);
 				data = 0;
 			} else {
-				printf("(%d)\n", count);
+				printf("(%d)\n", (int)count);
 				g_free(records);
 			}
 		}
