@@ -3,16 +3,16 @@
  *  Copyright (C) 1999-2004 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
@@ -52,7 +52,7 @@
 
 #define d(x) x
 
-#define CAMEL_IMAP4_SUMMARY_VERSION  2
+#define CAMEL_IMAP4_SUMMARY_VERSION  3
 
 static void camel_imap4_summary_class_init (CamelIMAP4SummaryClass *klass);
 static void camel_imap4_summary_init (CamelIMAP4Summary *summary, CamelIMAP4SummaryClass *klass);
@@ -118,8 +118,8 @@ camel_imap4_summary_init (CamelIMAP4Summary *summary, CamelIMAP4SummaryClass *kl
 	folder_summary->message_info_size = sizeof (CamelIMAP4MessageInfo);
 	folder_summary->content_info_size = sizeof (CamelIMAP4MessageContentInfo);
 	
-	summary->have_mlist = TRUE;
-
+	((CamelFolderSummary *) summary)->flags |= CAMEL_IMAP4_SUMMARY_HAVE_MLIST;
+	
 	summary->update_flags = TRUE;
 	summary->uidvalidity_changed = FALSE;
 }
@@ -159,14 +159,17 @@ imap4_header_load (CamelFolderSummary *summary, FILE *fin)
 		return -1;
 	}
 	
-	if (imap4_summary->version >= 2) {
+	if (imap4_summary->version == 2) {
 		/* check that we have Mailing-List info */
 		int have_mlist;
 		
 		if (camel_file_util_decode_fixed_int32 (fin, &have_mlist) == -1)
 			return -1;
 		
-		imap4_summary->have_mlist = have_mlist ? TRUE : FALSE;
+		if (have_mlist)
+			summary->flags |= CAMEL_IMAP4_SUMMARY_HAVE_MLIST;
+		else
+			summary->flags ^= CAMEL_IMAP4_SUMMARY_HAVE_MLIST;
 	}
 	
 	if (camel_file_util_decode_fixed_int32 (fin, &imap4_summary->uidvalidity) == -1)
@@ -186,9 +189,6 @@ imap4_header_save (CamelFolderSummary *summary, FILE *fout)
 	if (camel_file_util_encode_fixed_int32 (fout, CAMEL_IMAP4_SUMMARY_VERSION) == -1)
 		return -1;
 	
-	if (camel_file_util_encode_fixed_int32 (fout, imap4_summary->have_mlist) == -1)
-		return -1;
-	
 	if (camel_file_util_encode_fixed_int32 (fout, imap4_summary->uidvalidity) == -1)
 		return -1;
 	
@@ -434,29 +434,22 @@ decode_references (const char *string, int inreplyto)
 	struct _camel_header_references *refs, *r;
 	CamelSummaryReferences *references;
 	unsigned char md5sum[16];
-	guint32 i, n = 0;
-	MD5Context md5;
+	guint32 i, n;
 	
 	if (inreplyto) {
-		if (!(r = refs = camel_header_references_inreplyto_decode (string)))
+		if (!(refs = camel_header_references_inreplyto_decode (string)))
 			return NULL;
 	} else {
-		if (!(r = refs = camel_header_references_decode (string)))
+		if (!(refs = camel_header_references_decode (string)))
 			return NULL;
 	}
 	
-	while (r != NULL) {
-		r = r->next;
-		n++;
-	}
-	
+	n = camel_header_references_list_size (&refs);
 	references = g_malloc (sizeof (CamelSummaryReferences) + (sizeof (CamelSummaryMessageID) * (n - 1)));
 	references->size = n;
 	
-	for (i = 0, r = refs; i < n; i++, r = r->next) {
-		md5_init (&md5);
-		md5_update (&md5, r->id, strlen (r->id));
-		md5_final (&md5, md5sum);
+	for (i = 0, r = refs; r != NULL; i++, r = r->next) {
+		md5_get_digest (r->id, strlen (r->id), md5sum);
 		memcpy (references->references[i].id.hash, md5sum, sizeof (references->references[i].id.hash));
 	}
 	
@@ -999,6 +992,7 @@ untagged_fetch_all (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 ind
 			CamelMimeParser *parser;
 			unsigned char *literal;
 			const char *str;
+			char *mlist;
 			size_t n;
 			
 			/* '(' */
@@ -1057,7 +1051,9 @@ untagged_fetch_all (CamelIMAP4Engine *engine, CamelIMAP4Command *ic, guint32 ind
 				h = camel_mime_parser_headers_raw (parser);
 				
 				/* find our mailing-list header */
-				iinfo->info.mlist = camel_header_raw_check_mailing_list (&h);
+				mlist = camel_header_raw_check_mailing_list (&h);
+				iinfo->info.mlist = camel_pstring_strdup (mlist);
+				g_free (mlist);
 				
 				/* check if we possibly have attachments */
 				if ((str = camel_header_raw_find (&h, "Content-Type", NULL))) {
@@ -1451,12 +1447,16 @@ camel_imap4_summary_flush_updates (CamelFolderSummary *summary, CamelException *
 	/* FIXME: what do we do if replaying the journal fails? */
 	camel_offline_journal_replay (journal, NULL);
 	
-	if (imap4_folder->enable_mlist && !imap4_summary->have_mlist) {
+	if (imap4_folder->enable_mlist && !(summary->flags & CAMEL_IMAP4_SUMMARY_HAVE_MLIST)) {
 		/* need to refetch all summary info to get info->mlist */
 		imap4_summary_clear (summary, FALSE);
 	}
 	
-	imap4_summary->have_mlist = imap4_folder->enable_mlist;
+	summary->flags = (summary->flags & ~CAMEL_IMAP4_SUMMARY_HAVE_MLIST);
+	if (imap4_folder->enable_mlist)
+		summary->flags |= CAMEL_IMAP4_SUMMARY_HAVE_MLIST;
+	else
+		summary->flags ^= CAMEL_IMAP4_SUMMARY_HAVE_MLIST;
 	
 	engine = ((CamelIMAP4Store *) summary->folder->parent_store)->engine;
 	scount = camel_folder_summary_count (summary);
