@@ -7,15 +7,15 @@
  *  Michael Zucchi <notzed@ximian.com>
 
  * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU General Public 
+ * modify it under the terms of version 2 of the GNU Lesser General Public 
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  * USA
@@ -701,7 +701,7 @@ e_sexp_term_eval(struct _ESExp *f, struct _ESExpTerm *t)
 		break;
 	case ESEXP_TERM_FUNC:
 		/* first evaluate all arguments to result types */
-		argv = g_alloca(sizeof(argv[0]) * t->value.func.termcount);
+		argv = alloca(sizeof(argv[0]) * t->value.func.termcount);
 		for (i=0;i<t->value.func.termcount;i++) {
 			argv[i] = e_sexp_term_eval(f, t->value.func.terms[i]);
 		}
@@ -903,7 +903,7 @@ parse_value(ESExp *f)
 		p(printf("got brace, its a list!\n"));
 		return parse_list(f, TRUE);
 	case G_TOKEN_STRING:
-		p(printf("got string\n"));
+		p(printf("got string '%s'\n", g_scanner_cur_value(gs).v_string));
 		t = parse_term_new(f, ESEXP_TERM_STRING);
 		t->value.string = g_strdup(g_scanner_cur_value(gs).v_string);
 		break;
@@ -922,7 +922,7 @@ parse_value(ESExp *f)
 		t->value.number = g_scanner_cur_value(gs).v_int;
 		if (negative)
 			t->value.number = -t->value.number;
-		p(printf("got int\n"));
+		p(printf("got int %d\n", t->value.number));
 		break;
 	case '#': {
 		char *str;
@@ -947,6 +947,7 @@ parse_value(ESExp *f)
 		break; }
 	case G_TOKEN_SYMBOL:
 		s = g_scanner_cur_value(gs).v_symbol;
+		p(printf("got symbol '%s'\n", s->name));
 		switch (s->type) {
 		case ESEXP_TERM_FUNC:
 		case ESEXP_TERM_IFUNC:
@@ -965,6 +966,7 @@ parse_value(ESExp *f)
 		}
 		break;
 	case G_TOKEN_IDENTIFIER:
+		p(printf("got unknown identifider '%s'\n", g_scanner_cur_value(gs).v_identifier));
 		e_sexp_fatal_error(f, "Unknown identifier: %s", g_scanner_cur_value(gs).v_identifier);
 		break;
 	default:
